@@ -6,6 +6,8 @@ from logging import getLogger
 import shutil
 
 from six.moves.urllib.parse import urlparse, urlunparse
+from binstar_client import errors
+import re
 
 
 log = getLogger('binstar.git')
@@ -42,3 +44,21 @@ def clone_repo(path):
     atexit.register(rmrepo)
 
     return tmp_dir
+
+
+def get_gitrepo(url):
+    # split branch from repo
+
+    if url.netloc != 'github.com':
+        raise errors.UserError("Currently only github.com urls are supported (got %s)" % url.netloc)
+
+    pat = re.compile('^/(?P<repo>[\w-]+/[\w-]+)(/tree/(?P<branch>[\w/]+))?(.git)?$')
+    match = pat.match(url.path)
+    if not match:
+        raise errors.UserError("URL path '%s' is not a git repo" % url.path)
+
+    groups = match.groupdict()
+    repo = groups.get('repo')
+    branch = groups.get('branch') or url.fragment or 'master'
+    builds = {'repo': repo, 'branch':branch}
+    return builds
